@@ -1,4 +1,6 @@
+import sys
+
 from thriftpyi.cli import main
 
 if __name__ == "__main__":
-    main()
+    sys.exit(main())
